@@ -635,6 +635,27 @@ urls = {"call":
                                "https://web.bevsa.com.uy/CurvasVectorPrecios/CurvasIndices/Indices/IndiceINDUI.aspx",
                                "https://web.bevsa.com.uy/CurvasVectorPrecios/CurvasIndices/Indices/IndiceITLUP.aspx"],
                            "provider": ["BEVSA"]}},
+        "deposits":
+            {"dl": {
+                "main": "https://www.bcu.gub.uy/Servicios-Financieros-SSF/Series%20IF/Depositos.xls"},
+                "source": {"direct": ["https://www.bcu.gub.uy/Servicios-Financieros-SSF/Series%20IF/Depositos.xls"],
+                           "indirect": [
+                               "https://www.bcu.gub.uy/Servicios-Financieros-SSF/Paginas/Series-estadisticas-Depositos.aspx"],
+                           "provider": ["BCU"]}},
+        "credits":
+            {"dl": {
+                "main": "https://www.bcu.gub.uy/Servicios-Financieros-SSF/Series%20IF/Creditos.xls"},
+                "source": {"direct": ["https://www.bcu.gub.uy/Servicios-Financieros-SSF/Series%20IF/Creditos.xls"],
+                           "indirect": [
+                               "https://www.bcu.gub.uy/Servicios-Financieros-SSF/Paginas/Series-Estadisticas-Creditos.aspx"],
+                           "provider": ["BCU"]}},
+        "rates":
+            {"dl": {
+                "main": "https://www.bcu.gub.uy/Servicios-Financieros-SSF/Series%20IF/tasas.xls"},
+                "source": {"direct": ["https://www.bcu.gub.uy/Servicios-Financieros-SSF/Series%20IF/tasas.xls"],
+                           "indirect": [
+                               "https://www.bcu.gub.uy/Servicios-Financieros-SSF/Paginas/Series-Estadisticas-Tasas.aspx"],
+                           "provider": ["BCU"]}},
         "cpi":
             {"dl": {
                 "main": "http://ine.gub.uy/c/document_library/get_file?uuid=2e92084a-94ec-4fec-b5ca-42b40d5d2826&groupId=10181"},
@@ -695,6 +716,14 @@ urls = {"call":
                               "indirect": [
                                   "https://www.gub.uy/ministerio-economia-finanzas/datos-y-estadisticas/datos/informacion-resultados-del-sector-publico"],
                               "provider": ["MEF"]}},
+        "taxes": {"dl": {
+            "main": "https://www.dgi.gub.uy/wdgi/afiledownload?2,4,865,O,S,0,19353%3BS%3B100%3B108,",
+            "report": f"https://www.dgi.gub.uy/wdgi/page?2,principal,dgi--datos-y-series-estadisticas--informes-mensuales-de-la-recaudacion-{dt.datetime.now().year},O,es,0,"},
+            "source": {"direct": ["https://www.dgi.gub.uy/wdgi/afiledownload?2,4,865,O,S,0,19353%3BS%3B100%3B108,"],
+                       "indirect": [
+                           "https://www.dgi.gub.uy/wdgi/page?2,principal,dgi--datos-y-series-estadisticas--serie-de-datos--recaudacion-anual-y-mensual-por-impuesto,O,es,0,",
+                           f"https://www.dgi.gub.uy/wdgi/page?2,principal,dgi--datos-y-series-estadisticas--informes-mensuales-de-la-recaudacion-{dt.datetime.now().year},O,es,0,"],
+                       "provider": ["DGI"]}},
         "public_debt": {"dl": {
             "main": "https://www.bcu.gub.uy/Estadisticas-e-Indicadores/Endeudamiento%20Pblico/resdspg.xls"},
                         "source": {"direct": [
@@ -1336,3 +1365,42 @@ cpi_details = {"2010_base": {
                      'CUIDADOS Y EFECTOS PERSONALES',
                      'TABACO',
                      'SERVICIOS DIVERSOS']}
+
+taxes_columns = ['IRAE - Rentas de Actividades Económicas',
+                 'IMEBA - Enajenación de Bienes Agropecuarios',
+                 'IRPF Cat I - Renta de las Personas Físicas',
+                 'IRPF Cat II - Rentas de las Personas Físicas',
+                 'IRNR - Rentas de No Residentes',
+                 'IASS - Asistencia a la Seguridad Social',
+                 'ISAFI - SA Financieras de Inversión',
+                 'IP Personas Jurídicas - Patrimonio',
+                 'IP Explotaciones Agropecuarias - Patrimonio',
+                 'IP Sobretasa - IP',
+                 'ICOSA - Control de las SA',
+                 'IP Personas Físicas - Patrimonio',
+                 'ITP - Transferencias Patrimoniales',
+                 'ITP Adicional - Transferencias Patrimoniales',
+                 'IVA - Valor Agregado',
+                 'IVA Mínimo - Pequeña Empresa',
+                 'IMESI - Específico Interno',
+                 'IMEBA Ad. MEVIR - Enajernación de Bienes Agropecuarios',
+                 'IMEBA Ad. INIA - Enajernación de Bienes Agropecuarios',
+                 'Impuesto a los Ingresos de las Compañías de Seguros',
+                 'FIS - Fondo de Inspección Sanitaria',
+                 'IRIC - Rentas de Industria Comercio',
+                 'COFIS - Contribución al Financiamiento Seguridad Social',
+                 'IMESSA - Específico a los Servicios de Salud',
+                 'Impuesto a las Comisiones',
+                 'Impuesto a las Ventas Forzadas',
+                 'Impuesto a las Tarjetas de Crédito',
+                 'ITEL - Telecomunicaciones',
+                 'Impuesto a los Ingresos le Los Organizadores de Sorteos',
+                 'ICOME - Compra de Moneda Extranjera',
+                 'Impuesto a la Compra - Venta de Bienes Remate Público',
+                 'Impuesto a las Cesiones de Derechos sobre Deportistas',
+                 'IMABA - Activos de las Empresas Bancarias',
+                 'ICOSIFI - Control del Sistema Financiero',
+                 'IRA - Rentas Agropecuarias',
+                 'IMAGRO - Actividades Agropecuaria',
+                 'Impuesto de Educación Primaria',
+                 'Recaudación Total de la DGI']
